# This module is automatically generated by autogen.sh. DO NOT EDIT.

from diagrams import Node
from pathlib import Path

class _Github(Node):
    _type = "github"
    _icon_dir = Path(__file__).parent.parent.parent / "resources/github"


class Actions_Runner(_Github):
    _icon = "actions_runner.png"

# Aliases
